tree_is_desc_or_self

Function tree_is_desc_or_self 

pub fn tree_is_desc_or_self<T: 'static>(
    tree: &TreeModel<T>,
    node: NodeId,
    ancestor: NodeId,
) -> bool
Whether node is ancestor or one of its descendants — the move cycle guard (you cannot drop a node into its own subtree).